<?xml version="1.0" encoding="UTF-8"?>
<!--
########################################################################
# metaf-sum.xsl 1.42
#   templates to transform XML to HTML or text for mode=summary
#
# copyright (c) metaf2xml 2006-2011
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
########################################################################
-->

<xsl:stylesheet
    xmlns:xsl = "http://www.w3.org/1999/XSL/Transform"
    xmlns:m = "http://metaf2xml.sourceforge.net/1.42"
    xmlns:t = "http://metaf2xml.sourceforge.net/1.42"
    exclude-result-prefixes = "m t"
    version = "1.0">

 <!-- this must be passed with "- -stringparam name value" from xsltproc -->
 <xsl:param name="lang"/>
 <xsl:param name="no_msg"/>

 <xsl:variable name="lang_used">
  <xsl:choose>
   <xsl:when test="$lang = 'en' or $lang = 'es' or $lang = 'ru'">
    <xsl:value-of select="$lang"/>
   </xsl:when>
   <xsl:when test="$lang = '' and (/data/options/@lang = 'en' or /data/options/@lang = 'es' or /data/options/@lang = 'ru')">
    <xsl:value-of select="/data/options/@lang"/>
   </xsl:when>
   <xsl:otherwise>de</xsl:otherwise>
  </xsl:choose>
 </xsl:variable>

 <xsl:variable name="trans" select="document('metaf-lang.xsl')/t:trans/t:lang[@lang=$lang_used]"/>

 <xsl:variable name="NM2KM" select="1.852"/>
 <xsl:variable name="FT2M" select="0.3048"/>
 <xsl:variable name="SM2M" select="1609.3412196"/> <!-- statute mile! -->
 <xsl:variable name="METER_PER_SEC2KT" select="3.6 div $NM2KM"/>
 <xsl:variable name="INHG2HPA" select="33.86388640341"/>

 <xsl:template match="data">
  <xsl:choose>
   <xsl:when test="boolean(m:reports)">
    <xsl:apply-templates select="m:reports"/>
   </xsl:when>
   <xsl:otherwise>
    <b>
    <xsl:value-of select="concat('ERROR: versions differ: XML: ', namespace-uri(*[last()]), ', metaf-sum.xsl: http://metaf2xml.sourceforge.net/1.42')"/>
    </b>
    <p /><xsl:text>&#10;</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="m:reports">
  <xsl:choose>
   <xsl:when test="not(boolean($trans))">
    <b>
    <xsl:value-of select="concat('ERROR: versions differ: metaf-lang.xsl: ', namespace-uri(document('metaf-lang.xsl')/*), ', metaf-sum.xsl: http://metaf2xml.sourceforge.net/1.42')"/>
    </b>
    <p /><xsl:text>&#10;</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:if test="boolean(m:metar)">
     <table border="1" cellpadding="3">
     <xsl:apply-templates select="m:metar"/>
     </table>
     <xsl:text>&#10;</xsl:text>
     <xsl:if test="boolean(m:synop)"><br /></xsl:if>
    </xsl:if>
    <xsl:if test="boolean(m:synop)">
     <table border="1" cellpadding="3">
     <xsl:apply-templates select="m:synop"/>
     </table>
     <xsl:text>&#10;</xsl:text>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="$method = 'html'">
   <xsl:comment> metaf-sum: 1.42 </xsl:comment>
   <xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="stationInfo">
  <xsl:param name="station"/>
  <xsl:if test="boolean($station)">
   <xsl:value-of select="concat(' (', $station, ', ', $trans/t:country[@o=$station/@ctry], ')')"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="m:metar">
  <xsl:if test="position() mod 15 = 1">
   <xsl:choose>
    <xsl:when test="not($no_msg != '')">
     <xsl:copy-of select="$trans/t:summaryHeader[@o='metarMsg']/tr"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:copy-of select="$trans/t:summaryHeader[@o='metar']/tr"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
  <xsl:element name="tr">
   <xsl:attribute name="title">
    <xsl:apply-templates select="m:obsStationId|m:callSign"/>
    <xsl:apply-templates select="m:obsStationId|m:callSign" mode="stationInfo">
     <xsl:with-param name="type" select="'ICAO'"/>
    </xsl:apply-templates>
   </xsl:attribute>
   <td nowrap="1">
   <xsl:choose>
    <xsl:when test="boolean(m:isSpeci)"><b>SPECI</b></xsl:when>
    <xsl:otherwise>METAR</xsl:otherwise>
   </xsl:choose>
   <xsl:apply-templates select="m:reportModifier/m:modifierType[@v = 'NIL' or @v = 'AUTO' or @v = 'COR' or @v = 'AMD' or @v = 'RTD']"/>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1"><xsl:apply-templates select="m:obsStationId"/></td>
   <xsl:text>&#9;</xsl:text>
   <td nowrap="1"><xsl:apply-templates select="m:obsTime"/></td>
   <xsl:text>&#9;</xsl:text>
   <xsl:variable name="gust">
    <xsl:apply-templates select="m:sfcWind/m:wind/m:gustSpeed|m:remark/m:peakWind/m:wind/m:speed|m:remark/m:sfcWind/m:wind/m:gustSpeed"/>
   </xsl:variable>
   <xsl:if test="not(boolean(m:sfcWind))">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$gust"/>
    </td><xsl:text>&#9;&#9;</xsl:text>
   </xsl:if>
   <xsl:apply-templates select="m:sfcWind">
    <xsl:with-param name="gust" select="$gust"/>
   </xsl:apply-templates>
   <xsl:choose>
    <xsl:when test="boolean(m:CAVOK)">
     <td colspan="3">CAVOK</td><xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:when>
    <xsl:otherwise>
     <td nowrap="1" align="right">
     <xsl:apply-templates select="m:visPrev[boolean(m:distance)]"/>
     <xsl:apply-templates select="m:visMin[boolean(m:distance)]"/>
     </td><xsl:text>&#9;</xsl:text>
     <td nowrap="1"><xsl:apply-templates select="m:weather"/></td>
     <xsl:text>&#9;</xsl:text>
     <td nowrap="1">
      <xsl:apply-templates select="m:cloud"/>
      <xsl:apply-templates select="m:visVert[boolean(m:distance)]"/>
     </td><xsl:text>&#9;</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
   <td nowrap="1" align="right">
   <xsl:apply-templates select="m:temperature/m:air[boolean(m:temp)]"/>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1" align="right">
   <xsl:if test="boolean(m:temperature/m:relHumid1)">
    <xsl:value-of select="concat(format-number(m:temperature/m:relHumid1/@v, '0'), '%')"/>
   </xsl:if>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1" align="right"><xsl:apply-templates select="m:QNH|m:QFE"/></td>
   <xsl:text>&#9;</xsl:text>
   <xsl:variable name="rows">
    <xsl:if test="boolean(m:trend[m:trendType/@v != 'NOSIG'])">
     <xsl:value-of select="count(m:trend[m:trendType/@v != 'NOSIG']) + 1"/>
    </xsl:if>
   </xsl:variable>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:if test="$rows > 1">
     <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    </xsl:if>
    <xsl:apply-templates select="m:remark/m:notRecognised"/>
   </xsl:element>
   <xsl:if test="not($no_msg != '')">
    <xsl:text>&#9;</xsl:text>
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:attribute name="style">font-family: monospace; font-size: 90%;</xsl:attribute>
     <xsl:if test="$rows > 1">
      <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
     </xsl:if>
     <xsl:element name="a">
      <xsl:attribute name="href">
       <xsl:value-of select="concat('metaf.pl?mode=latest&amp;type_metaf=metar&amp;msg_synop=&amp;msg_metaf=', @s,
       '&amp;type_synop=', /data/options/@type_synop,
       '&amp;lang=', /data/options/@lang,
       '&amp;format=', /data/options/@format,
       '&amp;src_metaf=', /data/options/@src_metaf,
       '&amp;src_synop=', /data/options/@src_synop,
       '&amp;hours=', /data/options/@hours)"/>
      </xsl:attribute>
      <xsl:choose>
       <xsl:when test="boolean(m:ERROR)">
        <xsl:value-of select="substring-before(m:ERROR/@s, '&lt;')"/>
        <b>
        <xsl:value-of select="substring-after(m:ERROR/@s, '> ')"/>
        </b>
       </xsl:when>
       <xsl:otherwise>
        <xsl:value-of select="@s"/>
       </xsl:otherwise>
      </xsl:choose>
     </xsl:element>
    </xsl:element>
   </xsl:if>
   </xsl:element>
   <xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="m:trend[m:trendType/@v != 'NOSIG']"/>
 </xsl:template>

 <xsl:template match="m:obsStationId|m:callSign">
  <xsl:value-of select="m:id/@v"/>
 </xsl:template>

 <xsl:template match="m:obsStationId|m:callSign" mode="stationInfo">
  <xsl:param name="type"/>
  <xsl:choose>
   <xsl:when test="name() = 'callSign'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@callsign=current()/m:id/@v]"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="$type = 'ICAO'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@icao=current()/m:id/@v]"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="$type = 'AAXX'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@wmo=current()/m:id/@v]"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="$type = 'BBXX'">
    <xsl:call-template name="stationInfo">
     <xsl:with-param name="station" select="document('stations.xml')//stations/id[@ship=current()/m:id/@v]"/>
    </xsl:call-template>
   </xsl:when>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="m:obsTime">
  <xsl:apply-templates select="m:timeAt"/>
 </xsl:template>

 <xsl:template match="m:visPrev">
  <xsl:call-template name="visibility">
   <xsl:with-param name="rnd_m" select="50"/>
   <xsl:with-param name="unitThreshold" select="1000"/>
  </xsl:call-template>
 </xsl:template>

 <xsl:template match="m:visVert">
  <xsl:value-of select="concat('VV', format-number(m:distance/@v, '000'))"/>
 </xsl:template>

 <xsl:template name="visibility">
  <xsl:param name="rnd_m"/>
  <xsl:param name="unitThreshold"/>
  <xsl:choose>
   <xsl:when test="m:distance/@q = 'isLess'">&lt;</xsl:when>
   <xsl:when test="m:distance/@q = 'isGreater'">&gt;</xsl:when>
   <xsl:when test="m:distance/@q = 'isEqualGreater'">&gt;=</xsl:when>
   <xsl:otherwise></xsl:otherwise>
  </xsl:choose>
  <xsl:variable name="amountMeter">
   <xsl:choose>
    <xsl:when test="m:distance/@u = 'M'">
     <xsl:value-of select="m:distance/@v"/>
    </xsl:when>
    <xsl:when test="m:distance/@u = 'KM'">
     <xsl:value-of select="m:distance/@v * 1000"/>
    </xsl:when>
    <xsl:when test="m:distance/@u = 'SM'">
     <xsl:value-of select="m:distance/@v * $SM2M"/>
    </xsl:when>
    <xsl:when test="m:distance/@u = 'FT'">
     <xsl:value-of select="m:distance/@v * $FT2M"/>
    </xsl:when>
     <xsl:when test="m:distance/@u = 'NM'">
      <xsl:value-of select="m:distance/@v * $NM2KM * 1000"/>
     </xsl:when>
   </xsl:choose>
  </xsl:variable>
  <xsl:choose>
   <xsl:when test="$amountMeter >= $unitThreshold">
    <xsl:value-of select="concat(format-number($amountMeter div 1000, '0.#'), $trans/t:units[@o='KM'])"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(format-number($amountMeter div $rnd_m, '#0') * $rnd_m, $trans/t:units[@o='M'])"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="boolean(m:compassDir)">
   <xsl:if test="m:compassDir/@q = 'isGrid'">GRID</xsl:if>
   <xsl:value-of select="concat(' ', m:compassDir/@v)"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="m:sfcWind">
  <xsl:param name="gust"/>
  <xsl:apply-templates select="m:wind">
   <xsl:with-param name="gust" select="$gust"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="m:wind">
  <xsl:param name="gust"/>
  <xsl:choose>
   <xsl:when test="boolean(m:invalidFormat|m:notAvailable)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$gust"/>
    </td><xsl:text>&#9;</xsl:text>
   </xsl:when>
   <xsl:when test="boolean(m:isCalm)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="concat($trans/t:t[@o='calmWind'], $gust)"/></td>
    <xsl:text>&#9;</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="dir">
     <xsl:if test="boolean(m:dirVariable)">VRB</xsl:if>
     <xsl:if test="boolean(m:dir)">
      <xsl:if test="m:dir/@q = 'isGrid'">GRID</xsl:if>
      <xsl:value-of select="$trans/t:compassDir16/t:arr[1+format-number(current()/m:dir/@v div 45 * 2, '0')]"/>
      <!--select="concat(m:dir/@v, '°')"/-->
      <xsl:if test="boolean(m:windVarLeft)">
       <xsl:value-of select="concat(' (', $trans/t:compassDir16/t:arr[1+format-number(current()/m:windVarLeft/@v div 45 * 2, '0')], '-', $trans/t:compassDir16/t:arr[1+format-number(current()/m:windVarRight/@v div 45 * 2, '0')], ')')"/>
      </xsl:if>
     </xsl:if>
    </xsl:variable>
    <xsl:choose>
     <xsl:when test="m:dir/@v = '0' and m:speed/@v = '0'">
      <td colspan="2" nowrap="1">
      <xsl:value-of select="concat($trans/t:t[@o='calmWind'], $gust)"/>
      </td>
      <xsl:text>&#9;</xsl:text>
     </xsl:when>
     <xsl:when test="boolean(m:speedNotAvailable)">
      <td><xsl:value-of select="$dir"/></td>
      <xsl:text>&#9;</xsl:text>
      <td></td>
     </xsl:when>
     <xsl:otherwise>
      <td nowrap="1"><xsl:value-of select="$dir"/></td>
      <xsl:text>&#9;</xsl:text>
      <td nowrap="1" align="right">
      <xsl:call-template name="speed2kt">
       <xsl:with-param name="speed" select="m:speed"/>
      </xsl:call-template>
      <xsl:value-of select="$gust"/>
      </td>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:text>&#9;</xsl:text>
 </xsl:template>

 <xsl:template match="m:gustSpeed|m:speed">
  <xsl:if test="position() = 1"> (^</xsl:if>
  <xsl:if test="position() != 1">, ^</xsl:if>
  <xsl:choose>
   <xsl:when test="name() = 'gustSpeed'">
    <xsl:call-template name="speed2kt">
     <xsl:with-param name="speed" select="."/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="name(../..) = 'highestGust'">
    <xsl:call-template name="speed2kt">
     <xsl:with-param name="speed" select="."/>
    </xsl:call-template>
    <xsl:apply-templates select="../../m:measurePeriod|../../m:timePeriod|../../m:timeBeforeObs"/>
   </xsl:when>
   <xsl:when test="name(../..) = 'peakWind'">
    <xsl:call-template name="speed2kt">
     <xsl:with-param name="speed" select="."/>
    </xsl:call-template>
    <xsl:apply-templates select="../../m:timeAt">
     <xsl:with-param name="need_type" select="1"/>
    </xsl:apply-templates>
   </xsl:when>
  </xsl:choose>
  <xsl:if test="position() = last()">)</xsl:if>
 </xsl:template>

 <xsl:template match="m:timeBeforeObs">
  <xsl:if test="position() = 1"><xsl:value-of select="'/'"/></xsl:if>
  <xsl:if test="position() != 1">,</xsl:if>
  <xsl:if test="boolean(m:hoursUnknown)">?</xsl:if>
  <xsl:if test="@occurred = 'Begin'">*</xsl:if>
  <xsl:if test="@occurred = 'End'">+</xsl:if>
  <xsl:if test="@occurred = 'At'">@</xsl:if>
  <xsl:if test="m:hours/@q = 'isGreater'">&gt;</xsl:if>
  <xsl:if test="m:hours/@q = 'isLess'">&lt;</xsl:if>
  <xsl:value-of select="m:hoursFrom/@v|m:hours/@v"/>
  <xsl:if test="boolean(m:hoursTill)">
   <xsl:value-of select="concat('-', m:hoursTill/@v)"/>
  </xsl:if>
  <xsl:text>h</xsl:text>
 </xsl:template>

 <xsl:template match="m:timePeriod">
  <xsl:value-of select="concat('/', @v)"/>
 </xsl:template>

 <xsl:template match="m:measurePeriod">
  <xsl:value-of select="concat('/', @v, 'm')"/>
 </xsl:template>

 <xsl:template name="speed2kt">
  <xsl:param name="speed"/>
  <xsl:if test="$speed/@q = 'isGreater'">&gt;</xsl:if>
  <xsl:variable name="speedkt">
   <xsl:choose>
    <xsl:when test="$speed/@u = 'KT'">
     <xsl:value-of select="$speed/@v"/>
    </xsl:when>
    <xsl:when test="$speed/@u = 'KMH'">
     <xsl:value-of select="$speed/@v div $NM2KM"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$speed/@v * $METER_PER_SEC2KT"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:value-of select="format-number($speedkt, '0.#')"/>
 </xsl:template>

 <xsl:template match="m:weather">
  <xsl:if test="position() != 1"><xsl:value-of select="' '"/></xsl:if>
  <xsl:apply-templates select="m:phenomDescr"/>
  <xsl:if test="boolean(m:inVicinity)">VC</xsl:if>
  <xsl:if test="boolean(m:invalidFormat)">?</xsl:if>
  <xsl:if test="boolean(m:NSW)">NSW</xsl:if>
  <xsl:if test="boolean(m:tornado)">TORNADO</xsl:if>
  <xsl:apply-templates select="m:descriptor"/>
  <xsl:apply-templates select="m:phenomSpec"/>
 </xsl:template>

 <xsl:template match="m:phenomDescr">
  <xsl:if test="@v = 'isHeavy'">+</xsl:if>
  <xsl:if test="@v = 'isLight'">-</xsl:if>
 </xsl:template>

 <xsl:template match="m:descriptor">
  <xsl:value-of select="@v"/>
 </xsl:template>

 <xsl:template match="m:phenomSpec">
  <xsl:value-of select="@v"/>
 </xsl:template>

 <xsl:template match="m:cloud">
  <xsl:if test="position() != 1"><xsl:value-of select="' '"/></xsl:if>
  <xsl:choose>
   <xsl:when test="boolean(m:invalidFormat|m:notAvailable)">
   </xsl:when>
   <xsl:when test="boolean(m:noClouds)">
    <xsl:value-of select="m:noClouds/@v"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="cloud">
     <xsl:value-of select="m:cloudCover/@v"/>
     <xsl:choose>
      <xsl:when test="boolean(m:baseBelowStation)">///</xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="cloudBaseVal"/>
      </xsl:otherwise>
     </xsl:choose>
     <xsl:if test="boolean(m:cloudType)">
      <xsl:value-of select="m:cloudType/@v"/>
     </xsl:if>
     <xsl:if test="boolean(m:cloudTypeNotAvailable)">///</xsl:if>
    </xsl:variable>
    <xsl:choose>
     <xsl:when test="boolean(m:isCeiling)">
      <b><xsl:value-of select="$cloud"/></b>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$cloud"/>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template name="cloudBaseVal">
  <xsl:if test="m:cloudBase/@q = 'isLess'">
   <xsl:text>&lt;</xsl:text>
  </xsl:if>
  <xsl:if test="m:cloudBase/@q = 'isGreater'">
   <xsl:text>&gt;</xsl:text>
  </xsl:if>
  <xsl:if test="m:cloudBase/@q = 'isEqualGreater'">
   <xsl:text>&gt;=</xsl:text>
  </xsl:if>
  <xsl:if test="m:cloudBase/@u = 'FT'">
   <xsl:value-of select="format-number(m:cloudBase/@v div 100, '000')"/>
  </xsl:if>
  <xsl:if test="m:cloudBase/@u = 'M'">
   <xsl:value-of select="format-number(m:cloudBase/@v div 100 div $FT2M, '00') * 10"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="m:air">
  <xsl:call-template name="printTemp">
   <xsl:with-param name="temp" select="."/>
  </xsl:call-template>
 </xsl:template>

 <xsl:template match="m:notRecognised|m:obsStationType|m:warning">
  <xsl:if test="position() > 1"><xsl:text> </xsl:text></xsl:if>
  <xsl:value-of select="@s"/>
 </xsl:template>

 <xsl:template name="printTemp">
  <xsl:param name="temp"/>
  <xsl:choose>
   <xsl:when test="$temp/m:temp/@u = 'C'">
    <xsl:value-of select="$temp/m:temp/@v"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="format-number(($temp/m:temp/@v - 32) div 1.8, '0.#')"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="m:stationPressure|m:QNH|m:SLP|m:QFE">
  <xsl:if test="boolean(m:inHg|m:hPa|m:mmHg)">
   <xsl:if test="position() != 1"><xsl:text> </xsl:text></xsl:if>
   <xsl:choose>
    <xsl:when test="name() = 'stationPressure'">SP</xsl:when>
    <xsl:otherwise><xsl:value-of select="name()"/></xsl:otherwise>
   </xsl:choose>
   <xsl:choose>
    <xsl:when test="boolean(m:hPa)">
     <xsl:value-of select="m:hPa/@v"/>
    </xsl:when>
    <xsl:when test="boolean(m:mmHg)">
     <xsl:value-of select="format-number(m:mmHg/@v div ($FT2M div 12 * 1000) * $INHG2HPA, '0')"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="format-number(m:inHg/@v * $INHG2HPA, '0')"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
  <xsl:if test="boolean(../m:remark/m:QNH|../m:remark/m:SLP|../m:remark/m:QFE)">
   <xsl:text> (</xsl:text>
   <xsl:apply-templates select="../m:remark/m:QNH|../m:remark/m:SLP|../m:remark/m:QFE"/>
   <xsl:text>)</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="m:remark">
  <xsl:variable name="rmk">
   <xsl:value-of select="name(child::*[last()])"/>
  </xsl:variable>
  <xsl:choose>
   <xsl:when test="$rmk = 'cloud'">
    <xsl:apply-templates select="m:cloud">
     <xsl:with-param name="s_list" select="m:cloud/@s"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="$rmk = 'visRwy'">
    <xsl:apply-templates select="m:visRwy">
     <xsl:with-param name="unitThreshold" select="1000"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="child::*[last()]"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="m:visMin">
  <xsl:text>, </xsl:text>
  <xsl:call-template name="visibility">
   <xsl:with-param name="rnd_m" select="10"/>
   <xsl:with-param name="unitThreshold" select="1000"/>
  </xsl:call-template>
  <xsl:text>&#9;</xsl:text>
 </xsl:template>

 <xsl:template match="m:trend">
  <tr>
  <td colspan="2"/><xsl:text>&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="m:trendType/@v"/>
  <xsl:if test="boolean(m:probability)">
   <xsl:value-of select="concat(' PROB ', m:probability/@v, '%')"/>
  </xsl:if>
  <xsl:apply-templates select="m:timeAt|m:timeFrom|m:timeTill">
   <xsl:with-param name="pre" select="' '"/>
   <xsl:with-param name="need_type" select="1"/>
  </xsl:apply-templates>
  </td><xsl:text>&#9;</xsl:text>
  <xsl:if test="not(boolean(m:sfcWind))">
   <td colspan="2"/><xsl:text>&#9;&#9;</xsl:text>
  </xsl:if>
  <xsl:apply-templates select="m:sfcWind"/>
  <xsl:choose>
   <xsl:when test="boolean(m:CAVOK)">
    <td colspan="3">CAVOK</td><xsl:text>&#9;&#9;&#9;</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1" align="right">
    <xsl:apply-templates select="m:visPrev[boolean(m:distance)]"/>
    <xsl:apply-templates select="m:visMin[boolean(m:distance)]"/>
    </td><xsl:text>&#9;</xsl:text>
    <td nowrap="1"><xsl:apply-templates select="m:weather"/></td>
    <xsl:text>&#9;</xsl:text>
    <td nowrap="1">
     <xsl:apply-templates select="m:cloud"/>
     <xsl:apply-templates select="m:visVert[boolean(m:distance)]"/>
    </td><xsl:text>&#9;</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
  <td colspan="3"/>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="m:timeAt|m:timeFrom|m:timeTill">
  <xsl:param name="pre"/>
  <xsl:param name="need_type"/>
  <xsl:if test="position() = 1"><xsl:value-of select="$pre"/></xsl:if>
  <xsl:if test="position() = 2"><xsl:value-of select="' '"/></xsl:if>
  <xsl:if test="$need_type">
   <xsl:choose>
    <xsl:when test="name() = 'timeAt'">@</xsl:when>
    <xsl:when test="name() = 'timeFrom'">FM </xsl:when>
    <xsl:otherwise>TL </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
  <xsl:if test="boolean(m:day)">
   <xsl:value-of select="concat(m:day/@v, '., ')"/>
  </xsl:if>
  <xsl:value-of select="concat(m:hour/@v, ':')"/>
  <xsl:choose>
   <xsl:when test="boolean(m:minute)">
    <xsl:value-of select="m:minute/@v"/>
   </xsl:when>
   <xsl:otherwise>00</xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="m:synop">
  <xsl:if test="position() mod 15 = 1">
   <xsl:choose>
    <xsl:when test="not($no_msg != '')">
     <xsl:copy-of select="$trans/t:summaryHeader[@o='synopMsg']/tr"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:copy-of select="$trans/t:summaryHeader[@o='synop']/tr"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
  <xsl:element name="tr">
   <xsl:attribute name="title">
    <xsl:apply-templates select="m:obsStationId|m:callSign"/>
    <xsl:apply-templates select="m:obsStationId|m:callSign" mode="stationInfo">
     <xsl:with-param name="type" select="m:obsStationType/m:stationType/@v"/>
    </xsl:apply-templates>
   </xsl:attribute>
   <td nowrap="1">
   <xsl:text>SYNOP</xsl:text>
   <xsl:apply-templates select="m:reportModifier/m:modifierType[@v = 'NIL' or @v = 'AUTO' or @v = 'COR' or @v = 'AMD' or @v = 'RTD']"/>
   </td>
   <xsl:text>&#9;</xsl:text>
   <td nowrap="1"><xsl:apply-templates select="m:obsStationType"/></td>
   <xsl:text>&#9;</xsl:text>
   <td nowrap="1"><xsl:apply-templates select="m:obsTime"/></td>
   <xsl:text>&#9;</xsl:text>
   <td nowrap="1"><xsl:apply-templates select="m:obsStationId|m:callSign"/></td>
   <xsl:text>&#9;</xsl:text>
   <td nowrap="1" align="right">
   <xsl:apply-templates select="m:visPrev[boolean(m:distance)]"/>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1">
   <xsl:if test="boolean(m:totalCloudCover/m:skyObscured)">?/8</xsl:if>
   <xsl:if test="boolean(m:totalCloudCover/m:oktas)">
    <xsl:value-of select="concat(m:totalCloudCover/m:oktas/@v, '/8')"/>
   </xsl:if>
   <xsl:if test="boolean(m:baseLowestCloud/m:from)">
    <xsl:text> </xsl:text>
    <xsl:if test="m:baseLowestCloud/m:from/@q = 'isEqualGreater'">
     <xsl:text>&gt;=</xsl:text>
    </xsl:if>
    <xsl:value-of select="m:baseLowestCloud/m:from/@v"/>
    <xsl:if test="boolean(m:baseLowestCloud/m:to)">
     <xsl:value-of select="concat('..', m:baseLowestCloud/m:to/@v)"/>
    </xsl:if>
    <xsl:value-of select="$trans/t:units[@o=current()/m:baseLowestCloud/m:from/@u]"/>
   </xsl:if>
   </td><xsl:text>&#9;</xsl:text>
   <xsl:variable name="gust">
    <xsl:apply-templates select="m:section3/m:highestGust/m:wind/m:speed|m:section5/m:highestGust/m:wind/m:speed|m:section5/m:peakWind/m:wind/m:speed"/>
   </xsl:variable>
   <xsl:if test="not(boolean(m:sfcWind))">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$gust"/>
    </td><xsl:text>&#9;&#9;</xsl:text>
   </xsl:if>
   <xsl:apply-templates select="m:sfcWind">
    <xsl:with-param name="gust" select="$gust"/>
   </xsl:apply-templates>
   <td nowrap="1" align="right">
   <xsl:apply-templates select="m:temperature/m:air[boolean(m:temp)]"/>
   <xsl:apply-templates select="m:section3/m:tempMaxPeriod[boolean(m:temp)]|m:section3/m:tempMinPeriod[boolean(m:temp)]|m:section3/m:tempMaxDaytime[boolean(m:temp)]|m:section3/m:tempMinNighttime[boolean(m:temp)]"/>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1" align="right">
   <xsl:if test="boolean(m:temperature/m:relHumid1)">
    <xsl:value-of select="concat(format-number(m:temperature/m:relHumid1/@v, '0'), '%')"/>
   </xsl:if>
   </td><xsl:text>&#9;</xsl:text>
   <td nowrap="1" align="right">
   <xsl:if test="boolean(m:stationPressure/m:hPa)">
    <xsl:apply-templates select="m:stationPressure"/>
    <xsl:apply-templates select="m:pressureChange[boolean(m:pressureChangeVal)]|m:section3/m:pressureChange[boolean(m:pressureChangeVal)]"/>
   </xsl:if>
   <xsl:if test="boolean(m:gpSurface/m:geopotential)">
    <xsl:if test="boolean(m:stationPressure/m:hPa)"><xsl:text> </xsl:text></xsl:if>
    <xsl:value-of select="concat(m:gpSurface/m:surface/@v, ': ', m:gpSurface/m:geopotential/@v)"/>
   </xsl:if>
   <xsl:if test="boolean(m:SLP) and boolean(m:stationPressure/m:hPa|m:gpSurface/m:geopotential)"><xsl:text> </xsl:text></xsl:if>
   <xsl:apply-templates select="m:SLP"/>
   <xsl:if test="not(boolean(m:stationPressure/m:hPa))">
    <xsl:apply-templates select="m:pressureChange[boolean(m:pressureChangeVal)]"/>
    <xsl:apply-templates select="m:section3/m:pressureChange[boolean(m:pressureChangeVal)]">
     <xsl:with-param name="pre" select="'SP '"/>
    </xsl:apply-templates>
   </xsl:if>
   </td><xsl:text>&#9;</xsl:text>
   <xsl:choose>
    <xsl:when test="boolean(m:precipHourly/m:precipAmount|m:precipHourly/m:traces|m:section3/m:precipHourly/m:precipAmount|m:section3/m:precipHourly/m:traces)">
     <xsl:apply-templates select="m:precipHourly/m:precipAmount|m:precipHourly/m:traces|m:section3/m:precipHourly/m:precipAmount|m:section3/m:precipHourly/m:traces"/>
    </xsl:when>
    <xsl:otherwise>
     <td colspan="3"/><xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
   <td nowrap="1">
   <xsl:choose>
    <xsl:when test="boolean(m:weatherSynop/m:weatherPresent|m:weatherSynop/m:weatherPresentSimple)">
     <xsl:apply-templates select="m:weatherSynop/m:weatherPresent|m:weatherSynop/m:weatherPresentSimple"/>
    </xsl:when>
    <xsl:when test="m:wxInd/m:wxIndVal/@v = 2 or m:wxInd/m:wxIndVal/@v = 5">-</xsl:when>
    <xsl:otherwise>?</xsl:otherwise>
   </xsl:choose>
   <xsl:apply-templates select="m:weatherSynop/m:weatherPast1|m:weatherSynop/m:weatherPast1Simple"/>
   <xsl:if test="(boolean(m:weatherSynop/m:weatherPast1) and m:weatherSynop/m:weatherPast1/@v != m:weatherSynop/m:weatherPast2/@v) or (boolean(m:weatherSynop/m:weatherPast1Simple) and m:weatherSynop/m:weatherPast1Simple/@v != m:weatherSynop/m:weatherPast2Simple/@v)">
    <xsl:apply-templates select="m:weatherSynop/m:weatherPast2|m:weatherSynop/m:weatherPast2Simple"/>
   </xsl:if>
   <xsl:apply-templates select="m:section3/m:weatherSynopAdd/m:weatherPresent|m:section3/m:weatherSynopAmplPast/m:weatherPresent|m:section3/m:weatherSynopAmpl/m:weatherPresent|m:section3/m:weatherSynopPast/m:weatherPresent"/>
   </td><xsl:text>&#9;</xsl:text>
   <xsl:choose>
    <xsl:when test="boolean(m:cloudTypes/m:skyObscured)">
     <td colspan="3">?/8</td>
     <xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:when>
    <xsl:when test="boolean(m:cloudTypes) and not(boolean(m:cloudTypes/m:notAvailable) or (boolean(m:cloudTypes/m:cloudTypeLowNA) and boolean(m:cloudTypes/m:cloudTypeMiddleNA) and boolean(m:cloudTypes/m:cloudTypeHighNA)))">
     <td nowrap="1">
     <xsl:choose>
      <xsl:when test="boolean(m:cloudTypes/m:oktasLow)">
       <xsl:value-of select="concat(m:cloudTypes/m:oktasLow/@v, '/8 ')"/>
      </xsl:when>
      <xsl:when test="m:cloudTypes/m:cloudTypeLow/@v = 0">0/8</xsl:when>
     </xsl:choose>
     <xsl:if test="m:cloudTypes/m:cloudTypeLow/@v = 1">CU fr</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeLow/@v = 2">CU con</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeLow/@v = 3">CB cal</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeLow/@v = 4">SC cugen</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeLow/@v = 5">SC</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeLow/@v = 6">ST neb</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeLow/@v = 7">ST/CU fra</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeLow/@v = 8">CU,SC</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeLow/@v = 9">CB cap</xsl:if>
     </td><xsl:text>&#9;</xsl:text>
     <td nowrap="1">
     <xsl:choose>
      <xsl:when test="boolean(m:cloudTypes/m:oktasMiddle)">
       <xsl:value-of select="concat(m:cloudTypes/m:oktasMiddle/@v, '/8 ')"/>
      </xsl:when>
      <xsl:when test="m:cloudTypes/m:cloudTypeMiddle/@v = 0">0/8</xsl:when>
     </xsl:choose>
     <xsl:if test="m:cloudTypes/m:cloudTypeMiddle/@v = 1">AS tr</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeMiddle/@v = 2">AS op/NS</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeMiddle/@v = 3">AC tr</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeMiddle/@v = 4">AC tr/len</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeMiddle/@v = 5">AC tr/op</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeMiddle/@v = 6">AC cugen/cbgen</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeMiddle/@v = 7">AC tr/op,AC,AS/NS</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeMiddle/@v = 8">AC cas/flo</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeMiddle/@v = 9">AC</xsl:if>
     </td><xsl:text>&#9;</xsl:text>
     <td nowrap="1">
     <xsl:choose>
      <xsl:when test="m:cloudTypes/m:cloudTypeHigh/@v = 0">0/8</xsl:when>
     </xsl:choose>
     <xsl:if test="m:cloudTypes/m:cloudTypeHigh/@v = 1">CI fib/unc</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeHigh/@v = 2">CI spi/cas/flo</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeHigh/@v = 3">CI spi cbgen</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeHigh/@v = 4">CI unc/fib</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeHigh/@v = 5">CI,CS</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeHigh/@v = 6">CI,CS</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeHigh/@v = 7">CS</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeHigh/@v = 8">CS</xsl:if>
     <xsl:if test="m:cloudTypes/m:cloudTypeHigh/@v = 9">CC</xsl:if>
     </td><xsl:text>&#9;</xsl:text>
    </xsl:when>
    <xsl:when test="boolean(m:cloudTypes/m:oktas)">
     <td nowrap="1" colspan="3">
     <xsl:value-of select="concat(m:cloudTypes/m:oktas/@v, '/8 ')"/>
     </td><xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:when>
    <xsl:otherwise>
     <td colspan="3"/><xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:choose>
    <xsl:when test="boolean(m:section3/m:cloudInfo)">
     <xsl:apply-templates select="m:section3/m:cloudInfo"/>
    </xsl:when>
    <xsl:otherwise>
     <td colspan="3"/><xsl:text>&#9;&#9;&#9;</xsl:text>
    </xsl:otherwise>
   </xsl:choose>
   <td nowrap="1">
   <xsl:apply-templates select="m:warning[@warningType='notProcessed']"/>
   </td>
   <xsl:if test="not($no_msg != '')">
    <xsl:text>&#9;</xsl:text>
    <td nowrap="1" style="font-family: monospace; font-size: 90%;">
    <xsl:element name="a">
     <xsl:attribute name="href">
      <xsl:value-of select="concat('metaf.pl?mode=latest&amp;type_synop=synop&amp;msg_metaf=&amp;msg_synop=', @s,
      '&amp;type_metaf=', /data/options/@type_metaf,
      '&amp;lang=', /data/options/@lang,
      '&amp;format=', /data/options/@format,
      '&amp;src_metaf=', /data/options/@src_metaf,
      '&amp;src_synop=', /data/options/@src_synop,
      '&amp;hours=', /data/options/@hours)"/>
     </xsl:attribute>
      <xsl:choose>
       <xsl:when test="boolean(m:ERROR)">
        <xsl:value-of select="substring-before(m:ERROR/@s, '&lt;')"/>
        <b>
        <xsl:value-of select="substring-after(m:ERROR/@s, '> ')"/>
        </b>
       </xsl:when>
       <xsl:otherwise>
        <xsl:value-of select="@s"/>
       </xsl:otherwise>
      </xsl:choose>
     </xsl:element>
    </td>
   </xsl:if>
  </xsl:element>
  <xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="m:pressureChange">
  <xsl:param name="pre"/>
  <xsl:variable name="sign">
   <xsl:if test="m:pressureChangeVal/@v > 0">+</xsl:if>
  </xsl:variable>
  <xsl:if test="position() = 1"> (</xsl:if>
  <xsl:if test="position() != 1">, </xsl:if>
  <xsl:value-of select="concat($pre, $sign, m:pressureChangeVal/@v)"/>
  <xsl:apply-templates select="m:timeBeforeObs"/>
  <xsl:if test="position() = last()">)</xsl:if>
 </xsl:template>

 <xsl:template match="m:modifierType">
  <xsl:value-of select="concat(' ', @v)"/>
 </xsl:template>

 <xsl:template match="m:weatherPresent|m:weatherPresentSimple">
  <xsl:variable name="weather">
   <xsl:choose>
    <xsl:when test="name() = 'weatherPresentSimple'">
     <xsl:value-of select="document('metaf-lang.xsl')//t:trans/t:weatherPresentSimpleSum/t:arr[current()/@v + 1]"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="document('metaf-lang.xsl')//t:trans/t:weatherPresentSum/t:arr[current()/@v + 1]"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:if test="name(..) = 'weatherSynop' or $weather != '-'">
   <xsl:if test="name(..) != 'weatherSynop'">, </xsl:if>
   <xsl:value-of select="$weather"/>
   <xsl:if test="name(..) != 'weatherSynop'">
    <xsl:apply-templates select="../m:timeBeforeObs"/>
   </xsl:if>
  </xsl:if>
 </xsl:template>

 <xsl:template match="m:weatherPast1|m:weatherPast1Simple|m:weatherPast2|m:weatherPast2Simple">
  <xsl:variable name="weather">
   <xsl:choose>
    <xsl:when test="name() = 'weatherPast1' or name() = 'weatherPast2'">
     <xsl:value-of select="document('metaf-lang.xsl')//t:trans/t:weatherPastSum/t:arr[current()/@v + 1]"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="document('metaf-lang.xsl')//t:trans/t:weatherPastSimpleSum/t:arr[current()/@v + 1]"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:if test="$weather != '-'">
   <xsl:value-of select="concat(', ', $weather)"/>
   <xsl:apply-templates select="../m:timeBeforeObs"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="m:cloudInfo">
  <xsl:if test="position() &lt; 4">
   <xsl:variable name="cols">
    <xsl:choose>
     <xsl:when test="position() = last() and position() = 1">3</xsl:when>
     <xsl:when test="position() = last() and position() = 2">2</xsl:when>
     <xsl:otherwise>1</xsl:otherwise>
    </xsl:choose>
   </xsl:variable>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="colspan"><xsl:value-of select="$cols"/></xsl:attribute>
    <xsl:if test="boolean(m:cloudOktas/m:oktas)">
     <xsl:value-of select="concat(m:cloudOktas/m:oktas/@v, '/8 ')"/>
    </xsl:if>
    <xsl:if test="boolean(m:cloudType)">
     <xsl:value-of select="concat(m:cloudType/@v, ' ')"/>
    </xsl:if>
    <xsl:if test="boolean(m:cloudBase)">
     <xsl:if test="m:cloudBase/@q = 'isLess'">
      <xsl:text>&lt;</xsl:text>
     </xsl:if>
     <xsl:if test="m:cloudBase/@q = 'isGreater'">
      <xsl:text>&gt;</xsl:text>
     </xsl:if>
     <xsl:if test="m:cloudBase/@q = 'isEqualGreater'">
      <xsl:text>&gt;=</xsl:text>
     </xsl:if>
     <xsl:value-of select="concat(m:cloudBase/@v, $trans/t:units[@o=current()/m:cloudBase/@u])"/>
    </xsl:if>
    <xsl:if test="boolean(m:cloudBaseFrom)">
     <xsl:value-of select="concat(m:cloudBaseFrom/@v, '..', m:cloudBaseTo/@v, $trans/t:units[@o=current()/m:cloudBase/@u])"/>
    </xsl:if>
   </xsl:element>
   <xsl:text>&#9;</xsl:text>
   <xsl:if test="position() = last() and position() = 1">
    <xsl:text>&#9;&#9;</xsl:text>
   </xsl:if>
   <xsl:if test="position() = last() and position() = 2">
    <xsl:text>&#9;</xsl:text>
   </xsl:if>
  </xsl:if>
 </xsl:template>

 <xsl:template match="m:tempMaxPeriod|m:tempMinPeriod|m:tempMaxDaytime|m:tempMinNighttime">
  <xsl:if test="position() = 1"> (</xsl:if>
  <xsl:if test="position() != 1">, </xsl:if>
  <xsl:choose>
   <xsl:when test="name() = 'tempMaxPeriod' or name() = 'tempMaxDaytime'">^</xsl:when>
   <xsl:otherwise>v</xsl:otherwise>
  </xsl:choose>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="temp" select="."/>
  </xsl:call-template>
  <xsl:apply-templates select="m:timePeriod|m:timeBeforeObs"/>
  <xsl:if test="not(boolean(m:timePeriod|m:timeBeforeObs))">/</xsl:if>
  <xsl:if test="name() = 'tempMaxDaytime'">D</xsl:if>
  <xsl:if test="name() = 'tempMinNighttime'">N</xsl:if>
  <xsl:if test="position() = last()">)</xsl:if>
 </xsl:template>

 <xsl:template match="m:precipAmount|m:traces">
  <xsl:if test="position() &lt; 4">
   <xsl:variable name="cols">
    <xsl:choose>
     <xsl:when test="position() = last() and position() = 1">3</xsl:when>
     <xsl:when test="position() = last() and position() = 2">2</xsl:when>
     <xsl:otherwise>1</xsl:otherwise>
    </xsl:choose>
   </xsl:variable>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="colspan"><xsl:value-of select="$cols"/></xsl:attribute>
    <xsl:if test="name() = 'traces'">
     <xsl:value-of select="$trans/t:t[@o='traces']"/>
    </xsl:if>
    <xsl:if test="name() = 'precipAmount'">
     <xsl:value-of select="concat(@v, $trans/t:units[@o=current()/@u])"/>
    </xsl:if>
    <xsl:apply-templates select="../m:timePeriod|../m:timeBeforeObs"/>
   </xsl:element>
   <xsl:text>&#9;</xsl:text>
   <xsl:if test="position() = last() and position() = 1">
    <xsl:text>&#9;&#9;</xsl:text>
   </xsl:if>
   <xsl:if test="position() = last() and position() = 2">
    <xsl:text>&#9;</xsl:text>
   </xsl:if>
  </xsl:if>
 </xsl:template>

</xsl:stylesheet>
